﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using Com.Syncfusion.Charts.Enums;

namespace CustomDoughnutChart
{
    [Activity(Label = "CustomDoughnutChart", MainLauncher = true, Icon = "@drawable/icon")]
    public class MainActivity : Activity
    {
        LinearLayout linearLayout;

        TextView textView;

        protected override void OnCreate(Bundle bundle)
        {
            base.OnCreate(bundle);

            linearLayout = new LinearLayout(this);
            linearLayout.Orientation = Android.Widget.Orientation.Vertical;

            SfChart chart = new SfChart(this);
            chart.Title.Text = "Doughnut Chart";
            chart.SetBackgroundColor(Color.White);

            textView = new TextView(this);
            textView.Text = "DoughnutChart";

            ObservableArrayList dataPoints = new ObservableArrayList();

            dataPoints.Add(new ChartDataPoint("Jan", 42));
            dataPoints.Add(new ChartDataPoint("Feb", 44));
            dataPoints.Add(new ChartDataPoint("Mar", 53));
            dataPoints.Add(new ChartDataPoint("Apr", 64));
            dataPoints.Add(new ChartDataPoint("May", 75));
            dataPoints.Add(new ChartDataPoint("Jun", 83));

            DoughnutSeriesExt doughnutseries = new DoughnutSeriesExt(chart, textView);
            doughnutseries.DataSource = dataPoints;
            doughnutseries.DataMarker.ShowLabel = true;
            doughnutseries.DataMarkerPosition = CircularSeriesDataMarkerPosition.OutsideExtended;
            chart.Series.Add(doughnutseries);

            linearLayout.AddView(chart);

            SetContentView(linearLayout);
        }
    }

    public class DoughnutSeriesExt : DoughnutSeries
    {
        private SfChart chart;

        private TextView textView;

        public DoughnutSeriesExt(SfChart chart, TextView textView)
        {
            this.chart = chart;
            this.textView = textView;
        }

        protected override ChartSegment CreateSegment()
        {
            return new CustomDoughnutSegment(chart, textView);
        }
    }
    public class CustomDoughnutSegment : DoughnutSegment
    {
        private SfChart chart;

        private TextView textView;

        private Paint paint;
        public CustomDoughnutSegment(SfChart chart, TextView textView)
        {
            this.chart = chart;
            this.textView = textView;
            paint = new Paint();
        }

        public override void OnDraw(Canvas p0)
        {
            paint.Color = Android.Graphics.Color.Red;
            paint.SetStyle(Paint.Style.Fill);
            paint.TextSize = 20;
            p0.DrawText(this.textView.Text, this.chart.SeriesClipRect.CenterX() - 65, this.chart.SeriesClipRect.CenterY(), paint);
            base.OnDraw(p0);
        }
    }
}

